@@ -10,6 +10,7 @@ import subprocess
 import sys
 import xerox
 import yaml
+import colorama
 import termcolor
 
 
@@ -18,9 +19,10 @@ if sys.version_info < (3, 0):
 
 
 def main():
-  VERSION = '%(prog)s 0.3.3'
+  VERSION = '%(prog)s 0.3.4'
   DEFAULT_DATABASE_PATH = os.path.join('~', '.passwords.yaml.asc')
-  HAVE_COLOR_TERM = os.getenv('COLORTERM') or 'color' in os.getenv('TERM', 'default')
+  HAVE_COLOR_TERM = os.getenv('COLORTERM') or 'color' in os.getenv('TERM', 'default') or \
+    sys.platform == 'win32' # thanks to colorama
 
   # install silent Ctrl-C handler
   def handle_sigint(*_):
@@ -29,6 +31,7 @@ def main():
   signal.signal(signal.SIGINT, handle_sigint)
 
   # disable termcolor for terminals not supporting color
+  colorama.init()
   colored = termcolor.colored if HAVE_COLOR_TERM else lambda text, *args, **kwargs: text
 
   # color wrappers
@@ -101,7 +104,9 @@ def main():
         collect_entry(node, path)
       else:
         for (key, value) in node.items():
-          collect_entries(value, path + '.' + key if path else key)
+          # ignore entries in parentheses
+          if not (key.startswith('(') and key.endswith(')')):
+            collect_entries(value, path + '.' + key if path else key)
     else:
       collect_entry(node, path)
 
